import List from '@mui/material/List';
import { makeStyles } from '@material-ui/core'
import { useState,useEffect,useRef } from 'react';
import { useSelector, useDispatch } from 'react-redux';

import AlertInfo from '../../../reusableComponents/AlertInfo'
import ChatItem from './ChatItem';
import { notification,playNotificationWithoutPermission } from '../../../../helpers'
import { getState } from '../../../../redux/chats/selector'
import { getChatMemo } from '../../../../redux/chat/selector'
import { asyncGetChats } from '../../../../redux/chats/operations'
import { asyncStartChatById } from '../../../../redux/chat/operations'
import { actionRemoveChat } from '../../../../redux/chat/action'
import { actionScroll, actionIsOpen } from '../../../../redux/control/action'
import { getIsOpen } from '../../../../redux/control/selector';

const useStyles = makeStyles({
  list: {
    width: '100%',
    maxHeight: '890px',
    overflowY: 'scroll',
  '&::-webkit-scrollbar': {
    width: '0.4em'
  },
  '&::-webkit-scrollbar-track': {
    boxShadow: 'inset 0 0 6px rgba(0,0,0,0.00)',
    webkitBoxShadow: 'inset 0 0 6px rgba(0,0,0,0.00)',
    backgroundColor: '#eceeec',
  },
  '&::-webkit-scrollbar-thumb': {
    backgroundColor: '#ccc8c8',
    },
  "&::-webkit-scrollbar-thumb:focus": {
    backgroundColor: "#959595",
          },
  "&::-webkit-scrollbar-thumb:active": {
    backgroundColor: "#959595",
    },
  },
})

const ChatsList = () => {
  const classes = useStyles()
  const dispatch = useDispatch()
  const ref = useRef<any>(null)
  const [selectedIndex, setSelectedIndex] = useState<null | number>(null);
  const { total, chats } = useSelector(getState)
  const chat = useSelector(getChatMemo)
  const isOpen = useSelector(getIsOpen)

  const handleListItemClick = (i: number, companionId: string) => {
    dispatch(asyncStartChatById(companionId))
    dispatch(actionScroll(false))
    isOpen&&dispatch(actionIsOpen(''))
    setSelectedIndex(i);
  }

  const handleNewMsgs = (e: React.MouseEvent<HTMLButtonElement, MouseEvent>, i: number,companionId: string) => {
    e.stopPropagation()
    dispatch(asyncStartChatById(companionId))
    dispatch(actionScroll(true))
  }

  useEffect(() => {
    dispatch(asyncGetChats())
    const handleReset = () => dispatch(asyncGetChats())
    const idInterval = setInterval(handleReset, 3000);
    return () => clearInterval(idInterval);
  }, [dispatch]);

  useEffect(() => {
    const handleNotification= (companionId: string) => {
      dispatch(asyncStartChatById(companionId))
      dispatch(actionScroll(true))
    }
    if (chat.companionId&&!chats.find((el) => el.companionId === chat.companionId))dispatch(actionRemoveChat())
    if (ref.current) {
      ref.current.forEach(({total,seen}: any,i:number) => {
        const oldDifferent = total - seen
        const chat = chats[i]
        if(chat === undefined) return
        const newDifferent = chat.total - chat.seen
        if (newDifferent > oldDifferent && !chat.mute) {
          playNotificationWithoutPermission('http://localhost:3000/recive.mp3')
          notification(chat.name,() => handleNotification(chat.companionId))
        } 
      })
    }
      ref.current = chats
  }, [chats,chat,dispatch])  

  return total !== '0' ? (
    <List className={classes.list} component="nav"
      aria-label="main mailbox folders">
      {chats.map((el, i: number) => <ChatItem key={el.number} chat={el} selectedIndex={selectedIndex} i={i}
       handleListItemClick={handleListItemClick} handleNewMsgs={handleNewMsgs} setSelectedIndex={setSelectedIndex}/>)}
    </List>
  ):<AlertInfo name='You do not have any chats yet!' />;
}

export default ChatsList